@@ -13,7 +13,7 @@ def reload_kedro_mlflow(line=None, local_ns=None):
     )  # project_path is a global variable defined by init_kedro
     mlflow_config = get_mlflow_config()  # can only be called if a session exist
 
-    mlflow_client = MlflowClient(tracking_uri=mlflow_config.mlflow_tracking_uri)
+    mlflow_client = MlflowClient(tracking_uri=mlflow_config.server.mlflow_tracking_uri)
     global_variables = {"mlflow_client": mlflow_client}
     get_ipython().push(variables=global_variables)
     get_ipython().run_cell("import mlflow", "", "")
